==> v0.4.9.zip: libarea/app/Languages/en/app.php <==
<?php

/*
* The following language strings are used to translate the site core 
* (controllers and templates).
*
* Следующие языковые строки используются для переводя ядра сайта 
* (контроллеры и шаблоны).
*/

return [
    'home'              => 'Home',
    'catalog'           => 'Catalog',
    'feed'              => 'Feed',
    'test'              => 'Testing',
    'hi'                => 'Hey',
    'news'              => 'News',
    'team'              => 'Team',
    'teams'             => 'Teams',
    'owner'             => 'Owner',
    'top'               => 'TOP',
    'admin'             => 'Admin panel',
    'well'              => 'Good',
    'development'       => 'Development',
    'sort'              => 'Sort',
    'facets'            => 'Facets',
    'content'           => 'Content',
    'navigation'        => 'Navigation',
    'category'          => 'Category',
    'visibility'        => 'Visibility',
    'number'            => 'Number',
    'icon'              => 'Icon',
    'template'          => 'Template',
    'setting'           => 'Setting',
    'settings'          => 'Settings',
    'security'          => 'Password',
    'avatar'            => 'Avatar',
    'understands'       => 'Disassembled',
    'necessarily'       => 'Required to fill out',
    'create'            => 'Write',
    'writers'           => 'Writers',
    'by_deposit'        => 'By deposit',
    'welcome'           => 'Welcome',
    'create_account'    => 'Create an account',
    'saw'               => 'Saw',
    'bodies'            => 'Bodies',
    'thanks'            => 'Thanks',
    'whisper'           => 'Whisper',
    'report'            => 'Rreport',
    'reports'           => 'Rreports',
    'time'              => 'Time',
    'deleted'           => 'Deleted',
    'remote'            => 'Remote',
    'like'              => 'like',
    'recommended'       => 'Recommended',
    'notification'      => 'notification',
    'notifications'     => 'Notifications',
    'preferences'       => 'Preferences',
    'action'            => 'Action',
    'domain'            => 'Domain',
    'domains'           => 'Domains',
    'blog'              => 'Blog',
    'blogs'             => 'Blogs',
    'topics'            => 'Topics',
    'topic'             => 'Topic',
    'parent'            => 'Parent',
    'authorization'     => 'Authorization',
    'sign_in'           => 'Sign in',
    'sign_out'          => 'Sign out',
    'registration'      => 'Registration',
    'advertising'       => 'Advertising',
    'private_messages'  => 'Private messages',
    'post_merged'       => 'Post merged',
    'post_appearance'   => 'Post appearance',
    'id_merged_post'    => 'The ID of the post that this post will be merged with',
    'post_merged_info'  => 'This is an important step. Find the ID manually, or 0 - cancel the merge',
    'it_read'           => 'Has been read',
    'all_messages'      => 'All messages',
    'send_message'      => 'Dialog',
    'dialogues'         => 'Dialogs',
    'dialogue'          => 'Send a message',
    'write_message'     => 'To write a message',
    'send'              => 'Send',
    'information'       => 'Information',
    'donate'            => 'Support the project', 
    'review'            => 'Review',
    'contacts'          => 'Contacts',
    'city'              => 'City',
    'remember_me'       => 'To remember me',
    'banned'            => 'Banned',
    'ban_it'            => 'Ban',
    'unban'             => 'Unban',
    'reset'             => 'Reset',
    'invited_guests'    => 'Invited',
    'nickname'          => 'Nickname',
    'name'              => 'Имя',
    'password'          => 'Password',
    'new_password'      => 'New Password',
    'repeat'            => 'Repeat',
    'show'              => 'Show',
    'new'               => 'New',
    'new_ones'          => 'New',
    'old'               => 'Old',
    'code'              => 'The code',
    'invite'            => 'Invite',
    'invites'           => 'Invites',
    'view'              => 'View',
    'views'             => 'Views',
    'profile'           => 'Profile',
    'title'             => 'Title',
    'seo_title'         => 'Title (for SEO)',
    'heading'           => 'Heading',
    'to_extract'        => 'Extract',
    'discussion'        => 'Discussion',
    'description'       => 'Description',
    'meta_description'  => 'Meta Description',
    'short_description' => 'Short description',
    'favorites'         => 'Bookmarks',
    'long'              => 'long',
    'created_by'        => 'Created',
    'help'              => 'Help',
    'statistics'        => 'Statistics',
    'privacy'           => 'Confidentiality',
    'about'             => 'About Us',
    'about_me'          => 'About myself',
    'riddle'            => 'Riddle',
    'more'              => 'More',
    'see_more'          => 'See more',
    'read_more'         => 'Read more',
    'crop_post'         => 'Crop post',
    'other'             => 'Other',
    'official'          => 'off',
    'community'         => 'community',
    'trust_level'       => 'Trust level',
    'search'            => 'Search',
    'find'              => 'To find',
    'up'                => 'Up',
    'user'              => 'User',
    'users'             => 'Users',
    'page'              => 'Page',
    'read'              => 'Read',
    'reads'             => 'Reads',
    'reading'           => 'I read',
    'is_reading'        => 'Is reading',
    'subscribed'        => 'Signed',
    'unsubscribed'      => 'Unsubscribed',
    'unsubscribe'       => 'Unsubscribe',
    'subscribe'         => 'Subscribe',
    'approved'          => 'Approved',
    'remove'            => 'Delete',
    'recover'           => 'Reestablish',
    'download'          => 'Download',
    'password_recovery' => 'Password recovery',
    'draft_post'        => 'Is this a draft post',
    'drafts'            => 'Drafts',
    'cancel'            => 'Cancel',
    'reply'             => 'Reply',
    
    // Editor
    'foto'              => 'Foto',
    'bold'              => 'Bold',
    'strikethrough'     => 'Cross out',
    'italic'            => 'Italic',
    'quote'             => 'Quote',
    'link'              => 'Link',
    'preview'           => 'Preview',
    'toggle_two'        => 'Two windows',
    'fullscreen'        => 'Full screen',
    'spoiler'           => 'Spoiler',
    'spoiler_auth'      => 'Only for authorized',
    'select_image'      => 'Please select an image',
    'drop_image'        => 'Drag an image to upload it.',
    'attach_files'      => 'Files can be pasted from clipboard.',

    'view_policy'       => 'Only members can see the content',
    'entry_policy'      => 'Approve new members',
    
    'back'              => 'Back',
    'edit'              => 'Change',
    'save'              => 'Save',
    'add'               => 'Add',
    'add_post'          => 'Add post',
    'add_topic'         => 'Add Topic',
    'add_blog'          => 'Add blog',
    'add_category'      => 'Add category',
    'edit_category'     => 'Change category',
    'edit_post'         => 'Edit post',
    'edit_topic'        => 'Edit Topic',
    'edit_blog'         => 'Edit blog',
    'edit_page'         => 'Edit page',
    'edit_section'      => 'Edit Section',
    
    'published'         => 'Published in',

    'being_developed'   => 'Under development',
    'activity'          => 'Activity',
    'question'          => 'Question',
    'questions'         => 'Questions',
    'question_closed'   => 'The question is closed',
    'this_draft'        => 'This post is a draft',
    'no_cover'          => 'No covers yet',
    'no_invites'        => 'You have not created invitations',
    'no_content'        => 'Sorry, no content yet',
    'no_dialogs'        => 'Sorry, there are no dialogues yet',    
    'no_posts'          => 'Sorry, no posts yet',
    'no_favorites'      => 'Sorry, there are no bookmarks yet',
    'no_comments'       => 'Unfortunately, there are no comments yet',
    'no_answers'        => 'Sorry, no answers yet',
    'default'           => 'Default',
    'qa'                => 'Questions and answers',
    'answered'          => 'Answered',
    'post_translation'  => 'Post is translations',
    'translation'       => 'Translation',
    'format_Q&A'        => 'This is a question (will become a Q&A format)',
    'pin'               => 'Pin this post',
    
    'source'            => 'Source',
    'website'           => 'Website',
    'websites'          => 'Sites',
    'sites'             => 'Sites',
    'related'           => 'Related',
    'related_posts'     => 'Related posts',
    'parents'           => 'Parents',
    'children'          => 'Children',
    'bound_children'    => 'Related (children)',
    'bound_parents'     => 'Related (parents)',
    'root'              => 'Root',
    'root_help'         => 'Top (main) tree theme',
    'upper'             => 'Upper',
    'subtopics'         => 'Subtopics',
    'badge'             => 'Reward',
    'badges'            => 'Awards',
    'reward_user'       => 'Reward the participant',
    'for_example'       => 'For exampl',
    'ed'                => 'ed',
    'there_are'         => 'Aye',
    'yes'               => 'Yes',
    'no'                => 'No',
    'all'               => 'All',
    'alls'              => 'Alls',
    'you'               => 'You',
    'from'              => 'From',
    'by'                => 'By',
    'in'                => 'In',
    'and'               => 'And',
    'on'                => 'On',
    'for'               => 'For',
    'my'                => 'My',
    'publications'      => 'Publications',
    'posted'            => 'Posted',
    'selected_post'     => 'Featured post',
    'color'             => 'Colour',
    'text'              => 'Text',
    'author'            => 'Author',
    'characters'        => 'characters',
    'markdown'          => 'Supports Markdown',
    'write'             => 'Write',
    'in_profile'        => 'in profile',
    'request'           => 'Запрос',
    'results'           => 'Results',
    'format_cover_post' => 'Width, more than 500px. Orientation horizontal',

    'close'             => 'Close',
    'post_closed'       => 'Post closed',
    'repeat_password'   => 'Repeat password',
    'forgot_password'   => 'Forgot your password',
    'rules'             => 'Site rules',
    'restriction'       => 'Restrictions',
    
    'text_closed'       => 'Without authorization it is forbidden to view this hidden text',

    /* Date and time + events */
    'months'        => ['', 'January', 'February', 'Martha', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'],
    'today'         => 'Today',
    'yesterday'     => 'Yesterday',

    'num_message'   => ['Message', 'Messages', 'Messages'],
    'num_answer'    => ['Answer', 'Answers', 'Answers'],
    'num_post'      => ['Post', 'Posts', 'Posts'],
    'num_view'      => ['View', 'Views', 'Views'],
    'num_up'        => ['likes', 'likes', 'likes'],

    'comment'       => 'Comment',
    'comments'      => 'Comments',
    'answer'        => 'Answer',
    'answers'       => 'Answers',
    'message'       => 'Message',
    'messages'      => 'Messages',
    'post'          => 'Post',
    'posts'         => 'Posts',

    'language'          => 'Localization',
    'ru_language'       => 'Russian',
    'ua_language'       => 'Ukrainian',
    'en_language'       => 'English',
    'de_language'       => 'Deutsch',
    'fr_language'       => 'French',
    'zh_TW_language'    => 'Traditional Chinese',
    'zh_CN_language'    => 'Simplified Chinese',
    'ro_language'       => 'Romanian',

    'type'              => 'Type',
    'logo'              => 'logo',
    'last'              => 'Last thing',
    'recommended_size'  => 'Recommended Size',

    'you_answered'      => 'You already answered this question',
    'need_login'        => 'Login required',
    'no_auth'           => 'For an answer, you can <a href="/login">log in</a>',
    'auth_comm'         => 'You must be logged in to leave a comment',
    'not_registered'    => 'Post, reply, comment... <br>You have not registered yet',
    'invalid'           => 'Invalid',
    'agree_rules'       => 'By continuing, you agree to <a href="/info/article/privacy">Terms of Use</a> site',
    'reg_invite'        => 'Registration by invite',
    'details_here'      => 'Details here',
    'breaking_rules'    => 'Breaking the rules',

    'section'           => 'Section',
    'tag'               => 'Tag',
    'tags'              => 'Tags',
    'folder'            => 'Folder',
    'folders'           => 'Folders',
    'folders_s'         => 'Folders',
    'pages'             => 'Pages',
    'go_to'             => 'Go',
    'seo'               => 'SEO',
    'url'               => 'URL',
    'url_parsing'       => 'Article URL (for parsing)',
    'slug'              => 'SLUG',
    'email'             => 'Email',
    'wiki'              => 'Wiki',
    'edit_answer'       => 'Let\'s change the answer',
    'enter'             => 'Enter',
    'enter_password'    => 'Enter password',

    'rec_posts'         => 'recommended posts',
    'rec_posts_desc'    => 'Recommended posts in "{name}" selected manually.',
    'topic_subs'        => 'Subscribe to topics and read them in the feed',
    'i_read'            => 'I read',
 
    'message_PM'        => 'When the PM message came',
    'appeal_@'          => 'When contacted via @',

    'audits'            => 'Audit',
    'limits_invitation' => 'Your level of trust does not yet allow you to use invites',
    'can_send_link'     => 'can you send this link',
    'link_used'         => 'Link has been used',
    'medal_reg'         => 'Registration Medal',
    'registered'        => 'registered',
    'invitations_left'  => 'Remaining invitations',

    'first_days'            => 'Joined in the early days of the community launch',
    'nickname_replay'       => 'This nickname is already on the site',

    'english'               => 'English',
    'post_page'             => 'If filled out, then the Post will be a Page (in the documentation)',
    'work_email'            => 'Working email (for <b>account activation</b>)',

    'view_post_tl'          => 'Who can view the post (from which TL)',
    'invited_you'           => 'You were invited by a member from this site. Enter invite',
    'invite_features'       => 'You can invite friends',

    'content_deleted'   => '{name} deleted',

    'endless_scroll'        => 'Enable infinite scroll?',
    'notification_email'    => 'Notify by email',
    'notifications_limit'   => 'Showing last 100 notifications',

    /* Notifications and logs */
    'notif_add_pm'              => 'wrote to you {url}private message{a}',
    'notif_add_comment'         => 'commented {url}your answer{a}',
    'notif_add_comment_comment' => 'replied to {url}your comment{a}',
    'notif_add_answer'          => 'replied to {url}your post{a}',
    'notif_add_flag'            => 'enrolled {url}a complaint{a}',
    'notif_add_audit'           => 'required {url}content audit{a}',
    'notif_references_post'     => 'mentioned you in {url}post{a}',
    'notif_references_amswer'   => 'mentioned you in {url}answer{a}',
    'notif_references_comment'  => 'mentioned you in {url}comments{a}',
    'notif_add_website'         => 'added site {url}look it up{a}',
    'notif_edit_website'        => 'added site, {url}check it out{a}',
    'notif_approved_website'    => '(moderator) {url}changed (approved) your site{a}',
    'notif_add_website_comment' => '{url}commented site{a} to which you subscribed',
];

==> v0.5.0.zip: libarea/app/Languages/en/app.php <==
<?php

/*
* The following language strings are used to translate the site core 
* (controllers and templates).
*
* Следующие языковые строки используются для переводя ядра сайта 
* (контроллеры и шаблоны).
*/

return [
    'home'              => 'Home',
    'catalog'           => 'Catalog',
    'feed'              => 'Feed',
    'test'              => 'Testing',
    'hi'                => 'Hey',
    'news'              => 'News',
    'team'              => 'Team',
    'teams'             => 'Teams',
    'owner'             => 'Owner',
    'top'               => 'TOP',
    'admin'             => 'Admin panel',
    'well'              => 'Good',
    'development'       => 'Development',
    'sort'              => 'Sort',
    'facets'            => 'Facets',
    'content'           => 'Content',
    'navigation'        => 'Navigation',
    'category'          => 'Category',
    'visibility'        => 'Visibility',
    'number'            => 'Number',
    'icon'              => 'Icon',
    'template'          => 'Template',
    'setting'           => 'Setting',
    'settings'          => 'Settings',
    'security'          => 'Password',
    'avatar'            => 'Avatar',
    'understands'       => 'Disassembled',
    'necessarily'       => 'Required to fill out',
    'create'            => 'Write',
    'writers'           => 'Writers',
    'by_deposit'        => 'By deposit',
    'welcome'           => 'Welcome',
    'create_account'    => 'Create an account',
    'saw'               => 'Saw',
    'bodies'            => 'Bodies',
    'thanks'            => 'Thanks',
    'whisper'           => 'Whisper',
    'report'            => 'Rreport',
    'reports'           => 'Rreports',
    'time'              => 'Time',
    'deleted'           => 'Deleted',
    'remote'            => 'Remote',
    'like'              => 'like',
    'recommended'       => 'Recommended',
    'notification'      => 'notification',
    'notifications'     => 'Notifications',
    'preferences'       => 'Preferences',
    'action'            => 'Action',
    'domain'            => 'Domain',
    'domains'           => 'Domains',
    'blog'              => 'Blog',
    'blogs'             => 'Blogs',
    'topics'            => 'Topics',
    'topic'             => 'Topic',
    'parent'            => 'Parent',
    'authorization'     => 'Authorization',
    'sign_in'           => 'Sign in',
    'sign_out'          => 'Sign out',
    'registration'      => 'Registration',
    'advertising'       => 'Advertising',
    'private_messages'  => 'Private messages',
    'post_merged'       => 'Post merged',
    'post_appearance'   => 'Post appearance',
    'id_merged_post'    => 'The ID of the post that this post will be merged with',
    'post_merged_info'  => 'This is an important step. Find the ID manually, or 0 - cancel the merge',
    'it_read'           => 'Has been read',
    'all_messages'      => 'All messages',
    'send_message'      => 'Dialog',
    'dialogues'         => 'Dialogs',
    'dialogue'          => 'Send a message',
    'write_message'     => 'To write a message',
    'send'              => 'Send',
    'information'       => 'Information',
    'donate'            => 'Support the project', 
    'review'            => 'Review',
    'contacts'          => 'Contacts',
    'city'              => 'City',
    'remember_me'       => 'To remember me',
    'banned'            => 'Banned',
    'ban_it'            => 'Ban',
    'unban'             => 'Unban',
    'reset'             => 'Reset',
    'invited_guests'    => 'Invited',
    'nickname'          => 'Nickname',
    'name'              => 'Имя',
    'password'          => 'Password',
    'new_password'      => 'New Password',
    'repeat'            => 'Repeat',
    'show'              => 'Show',
    'new'               => 'New',
    'new_ones'          => 'New',
    'old'               => 'Old',
    'code'              => 'The code',
    'invite'            => 'Invite',
    'invites'           => 'Invites',
    'view'              => 'View',
    'views'             => 'Views',
    'profile'           => 'Profile',
    'title'             => 'Title',
    'seo_title'         => 'Title (for SEO)',
    'heading'           => 'Heading',
    'to_extract'        => 'Extract',
    'discussion'        => 'Discussion',
    'description'       => 'Description',
    'meta_description'  => 'Meta Description',
    'short_description' => 'Short description',
    'favorites'         => 'Bookmarks',
    'long'              => 'long',
    'created_by'        => 'Created',
    'help'              => 'Help',
    'statistics'        => 'Statistics',
    'privacy'           => 'Confidentiality',
    'about'             => 'About Us',
    'about_me'          => 'About myself',
    'riddle'            => 'Riddle',
    'more'              => 'More',
    'see_more'          => 'See more',
    'read_more'         => 'Read more',
    'crop_post'         => 'Crop post',
    'other'             => 'Other',
    'official'          => 'off',
    'community'         => 'community',
    'trust_level'       => 'Trust level',
    'search'            => 'Search',
    'find'              => 'To find',
    'up'                => 'Up',
    'user'              => 'User',
    'users'             => 'Users',
    'page'              => 'Page',
    'read'              => 'Read',
    'reads'             => 'Reads',
    'reading'           => 'I read',
    'is_reading'        => 'Is reading',
    'subscribed'        => 'Signed',
    'unsubscribed'      => 'Unsubscribed',
    'unsubscribe'       => 'Unsubscribe',
    'subscribe'         => 'Subscribe',
    'approved'          => 'Approved',
    'remove'            => 'Delete',
    'recover'           => 'Reestablish',
    'download'          => 'Download',
    'password_recovery' => 'Password recovery',
    'draft_post'        => 'Is this a draft post ?',
    'drafts'            => 'Drafts',
    'cancel'            => 'Cancel',
    'reply'             => 'Reply',
    
    // Editor
    'foto'              => 'Foto',
    'bold'              => 'Bold',
    'strikethrough'     => 'Cross out',
    'italic'            => 'Italic',
    'quote'             => 'Quote',
    'link'              => 'Link',
    'preview'           => 'Preview',
    'toggle_two'        => 'Two windows',
    'fullscreen'        => 'Full screen',
    'spoiler'           => 'Spoiler',
    'spoiler_auth'      => 'Only for authorized',
    'select_image'      => 'Please select an image',
    'drop_image'        => 'Drag an image to upload it.',
    'attach_files'      => 'Files can be pasted from clipboard.',

    'view_policy'       => 'Only members can see the content',
    'entry_policy'      => 'Approve new members',
    
    'back'              => 'Back',
    'edit'              => 'Change',
    'save'              => 'Save',
    'add'               => 'Add',
    'add_post'          => 'Add post',
    'add_topic'         => 'Add Topic',
    'add_blog'          => 'Add blog',
    'add_category'      => 'Add category',
    'edit_category'     => 'Change category',
    'edit_post'         => 'Edit post',
    'edit_topic'        => 'Edit Topic',
    'edit_blog'         => 'Edit blog',
    'edit_page'         => 'Edit page',
    'edit_section'      => 'Edit Section',
    
    'published'         => 'Published in',

    'being_developed'   => 'Under development',
    'activity'          => 'Activity',
    'question'          => 'Question',
    'questions'         => 'Questions',
    'question_closed'   => 'The question is closed',
    'this_draft'        => 'This post is a draft',
    'no_cover'          => 'No covers yet',
    'no_invites'        => 'You have not created invitations',
    'no_content'        => 'Sorry, no content yet',
    'no_dialogs'        => 'Sorry, there are no dialogues yet',    
    'no_posts'          => 'Sorry, no posts yet',
    'no_favorites'      => 'Sorry, there are no bookmarks yet',
    'no_comments'       => 'Unfortunately, there are no comments yet',
    'no_answers'        => 'Sorry, no answers yet',
    'default'           => 'Default',
    'qa'                => 'Questions and answers',
    'best_answer'       => 'Best Answer',
    'answered'          => 'Answered',
    'post_translation'  => 'Post is translations ?',
    'translation'       => 'Translation',
    'format_Q&A'        => 'This is a question (will become a Q&A format) ?',
    'pin'               => 'Pin this post ?',
    
    'source'            => 'Source',
    'website'           => 'Website',
    'websites'          => 'Sites',
    'sites'             => 'Sites',
    'related'           => 'Related',
    'related_posts'     => 'Related posts',
    'parents'           => 'Parents',
    'children'          => 'Children',
    'bound_children'    => 'Related (children)',
    'bound_parents'     => 'Related (parents)',
    'root'              => 'Root',
    'root_help'         => 'Top (main) tree theme',
    'upper'             => 'Upper',
    'subtopics'         => 'Subtopics',
    'badge'             => 'Reward',
    'badges'            => 'Awards',
    'reward_user'       => 'Reward the participant',
    'for_example'       => 'For exampl',
    'ed'                => 'ed',
    'there_are'         => 'Aye',
    'yes'               => 'Yes',
    'no'                => 'No',
    'all'               => 'All',
    'alls'              => 'Alls',
    'you'               => 'You',
    'from'              => 'From',
    'by'                => 'By',
    'in'                => 'In',
    'and'               => 'And',
    'on'                => 'On',
    'for'               => 'For',
    'my'                => 'My',
    'publications'      => 'Publications',
    'posted'            => 'Posted',
    'selected_post'     => 'Featured post',
    'color'             => 'Colour',
    'text'              => 'Text',
    'author'            => 'Author',
    'characters'        => 'characters',
    'markdown'          => 'Supports Markdown',
    'write'             => 'Write',
    'in_profile'        => 'in profile',
    'request'           => 'Запрос',
    'results'           => 'Results',
    'format_cover_post' => 'Width, more than 500px. Orientation horizontal',

    'close'             => 'Close',
    'post_closed'       => 'Post closed ?',
    'repeat_password'   => 'Repeat password',
    'forgot_password'   => 'Forgot your password',
    'rules'             => 'Site rules',
    'restriction'       => 'Restrictions',
    
    'text_closed'       => 'Without authorization it is forbidden to view this hidden text',

    /* Date and time + events */
    'months'        => ['', 'January', 'February', 'Martha', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'],
    'today'         => 'Today',
    'yesterday'     => 'Yesterday',

    'num_message'   => ['Message', 'Messages', 'Messages'],
    'num_answer'    => ['Answer', 'Answers', 'Answers'],
    'num_post'      => ['Post', 'Posts', 'Posts'],
    'num_view'      => ['View', 'Views', 'Views'],
    'num_up'        => ['likes', 'likes', 'likes'],

    'comment'       => 'Comment',
    'comments'      => 'Comments',
    'answer'        => 'Answer',
    'answers'       => 'Answers',
    'message'       => 'Message',
    'messages'      => 'Messages',
    'post'          => 'Post',
    'posts'         => 'Posts',

    'language'          => 'Localization',
    'ru_language'       => 'Russian',
    'ua_language'       => 'Ukrainian',
    'en_language'       => 'English',
    'de_language'       => 'Deutsch',
    'fr_language'       => 'French',
    'zh_TW_language'    => 'Traditional Chinese',
    'zh_CN_language'    => 'Simplified Chinese',
    'ro_language'       => 'Romanian',
    'ar_language'       => 'Arabic',

    'type'              => 'Type',
    'logo'              => 'logo',
    'last'              => 'Last thing',
    'recommended_size'  => 'Recommended Size',

    'you_answered'      => 'You already answered this question',
    'need_login'        => 'Login required',
    'no_auth'           => 'For an answer, you can <a href="/login">log in</a>',
    'auth_comm'         => 'You must be logged in to leave a comment',
    'not_registered'    => 'Post, reply, comment... <br>You have not registered yet',
    'invalid'           => 'Invalid',
    'agree_rules'       => 'By continuing, you agree to <a href="/info/article/privacy">Terms of Use</a> site',
    'reg_invite'        => 'Registration by invite',
    'details_here'      => 'Details here',
    'breaking_rules'    => 'Breaking the rules',

    'section'           => 'Section',
    'tag'               => 'Tag',
    'tags'              => 'Tags',
    'folder'            => 'Folder',
    'folders'           => 'Folders',
    'folders_s'         => 'Folders',
    'pages'             => 'Pages',
    'go_to'             => 'Go',
    'seo'               => 'SEO',
    'url'               => 'URL',
    'url_parsing'       => 'Article URL (for parsing)',
    'slug'              => 'SLUG',
    'email'             => 'Email',
    'wiki'              => 'Wiki',
    'edit_answer'       => 'Let\'s change the answer',
    'enter'             => 'Enter',
    'enter_password'    => 'Enter password',

    'rec_posts'         => 'recommended posts',
    'rec_posts_desc'    => 'Recommended posts in "{name}" selected manually.',
    'topic_subs'        => 'Subscribe to topics and read them in the feed',
    'i_read'            => 'I read',
 
    'message_PM'        => 'When the PM message came',
    'appeal_@'          => 'When contacted via @',

    'audits'            => 'Audit',
    'limits_invitation' => 'Your level of trust does not yet allow you to use invites',
    'can_send_link'     => 'can you send this link',
    'link_used'         => 'Link has been used',
    'medal_reg'         => 'Registration Medal',
    'registered'        => 'registered',
    'invitations_left'  => 'Remaining invitations',

    'first_days'            => 'Joined in the early days of the community launch',
    'nickname_replay'       => 'This nickname is already on the site',

    'english'               => 'English',
    'post_page'             => 'If filled out, then the Post will be a Page (in the documentation)',
    'work_email'            => 'Working email (for <b>account activation</b>)',

    'view_post_tl'          => 'Who can view the post (from which TL)',
    'invited_you'           => 'You were invited by a member from this site. Enter invite',
    'invite_features'       => 'You can invite friends',

    'content_deleted'   => '{name} deleted',

    'endless_scroll'        => 'Enable infinite scroll?',
    'notification_email'    => 'Notify by email',
    'notifications_limit'   => 'Showing last 100 notifications',

    'ignored'               => 'Ignored',    
    'ignored_users'         => 'Ignored users',
    'ignored_users_help'    => 'Users whose posts you will not see in the feed.',
    'ignored_no'            => 'You don\'t have users that you ignore.', 

    /* Notifications and logs */
    'notif_add_pm'              => 'wrote to you {url}private message{a}',
    'notif_add_comment'         => 'commented {url}your answer{a}',
    'notif_add_comment_comment' => 'replied to {url}your comment{a}',
    'notif_add_answer'          => 'replied to {url}your post{a}',
    'notif_add_flag'            => 'enrolled {url}a complaint{a}',
    'notif_add_audit'           => 'required {url}content audit{a}',
    'notif_references_post'     => 'mentioned you in {url}post{a}',
    'notif_references_amswer'   => 'mentioned you in {url}answer{a}',
    'notif_references_comment'  => 'mentioned you in {url}comments{a}',
    'notif_add_website'         => 'added site {url}look it up{a}',
    'notif_edit_website'        => 'added site, {url}check it out{a}',
    'notif_approved_website'    => '(moderator) {url}changed (approved) your site{a}',
    'notif_add_website_comment' => '{url}commented site{a} to which you subscribed',
];
